<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="gl_ES">
<context>
    <name>UninstallOption</name>
    <message>
        <location filename="../uninstalloption.cpp" line="39"/>
        <source>Restore the old file associations and clean up the registry</source>
        <translation>Restaurar as antigas asociacións de ficheiros e limpar o rexistro</translation>
    </message>
</context>
</TS>
